@@ -35,6 +35,7 @@ from bxcommon.utils import memory_utils, convert, performance_utils
 from bxcommon.utils.alarm_queue import AlarmQueue, AlarmId
 from bxcommon.utils.blockchain_utils import bdn_tx_to_bx_tx
 from bxcommon.common_opts import CommonOpts
+from bxcommon.utils.expiring_dict import ExpiringDict
 from bxcommon.utils.stats.block_statistics_service import block_stats
 from bxcommon.utils.stats.memory_statistics_service import memory_statistics
 from bxcommon.utils.stats.node_info_service import node_info_statistics
@@ -42,7 +43,7 @@ from bxcommon.utils.stats.node_statistics_service import node_stats_service
 from bxcommon.utils.stats.throughput_service import throughput_statistics
 from bxcommon.utils.stats.transaction_statistics_service import tx_stats
 from bxcommon.utils.transaction_short_id_buckets import TransactionShortIdBuckets
-from bxutils import log_messages
+from bxutils import log_messages, utils
 from bxutils import logging
 from bxutils.exceptions.connection_authentication_error import \
     ConnectionAuthenticationError
@@ -74,6 +75,8 @@ class AbstractNode:
         node_ssl_service: NodeSSLService,
         connection_pool: Optional[ConnectionPool] = None
     ):
+        # Event handling queue for delayed events
+        self.alarm_queue = AlarmQueue()
         self.node_ssl_service = node_ssl_service
         logger.debug("Initializing node of type: {}", self.NODE_TYPE)
         self.server_endpoints = [
@@ -86,6 +89,11 @@ class AbstractNode:
         self.opts: CommonOpts = opts
         self.pending_connection_requests: Set[ConnectionPeerInfo] = set()
         self.pending_connection_attempts: Set[ConnectionPeerInfo] = set()
+        self.recent_connections: ExpiringDict[str, int] = ExpiringDict(
+            self.alarm_queue,
+            constants.THROTTLE_RECONNECT_TIME_S,
+            name="recent_connections"
+        )
         self.outbound_peers: Set[OutboundPeerModel] = opts.outbound_peers.copy()
 
         if connection_pool is not None:
@@ -98,9 +106,6 @@ class AbstractNode:
 
         self.num_retries_by_ip: Dict[Tuple[str, int], int] = defaultdict(int)
 
-        # Event handling queue for delayed events
-        self.alarm_queue = AlarmQueue()
-
         self.init_node_status_logging()
         self.init_throughput_logging()
         self.init_node_info_logging()
@@ -207,6 +212,13 @@ class AbstractNode:
     ) -> None:
         pass
 
+    def report_connection_attempt(self, ip_address: str) -> int:
+        if ip_address in self.recent_connections:
+            self.recent_connections[ip_address] += 1
+        else:
+            self.recent_connections.add(ip_address, 1)
+        return self.recent_connections[ip_address]
+
     def connection_exists(
         self,
         ip: str,
@@ -224,7 +236,7 @@ class AbstractNode:
             ConnectionPeerInfo(socket_connection.endpoint, AbstractConnection.CONNECTION_TYPE)
         )
         ip, port = socket_connection.endpoint
-        peer_info = None
+        peer_info: Optional[AuthenticatedPeerInfo] = None
         if socket_connection.is_ssl:
             try:
                 peer_info = self._get_socket_peer_info(
@@ -235,7 +247,8 @@ class AbstractNode:
                 socket_connection.mark_for_close(should_retry=False)
                 return None
 
-            if self.connection_exists(ip, port, peer_info.peer_id):
+            if self.connection_exists(ip, port, peer_info.peer_id)\
+                    and peer_info.connection_type != ConnectionType.RELAY_PROXY:
                 logger.debug(
                     "Duplicate connection attempted to: {}:{} (peer id: {}). "
                     "Dropping.",
@@ -286,7 +299,7 @@ class AbstractNode:
         logger.info("Failed to connect to: {}, {}.", peer_info, error)
 
     def log_closed_connection(self, connection: AbstractConnection):
-        if ConnectionState.ESTABLISHED not in connection.state:
+        if not connection.established:
             logger.info("Failed to connect to: {}.", connection)
         else:
             logger.info("Closed connection: {}", connection)
@@ -316,8 +329,12 @@ class AbstractNode:
                 if rem_conn:
                     rem_conn.mark_for_close(False)
 
-        # Connect to peers not in our known pool
-        for peer in outbound_peer_models:
+        # Connect to peers not in our known pool or in opts.outbound_peers
+        new_peer_models = set()
+        new_peer_models.update(old_peers)
+        new_peer_models.update(outbound_peer_models)
+        new_peer_models.difference_update(remove_peers)
+        for peer in new_peer_models:
             peer_ip = peer.ip
             peer_port = peer.port
             if self.should_connect_to_new_outbound_peer(peer):
@@ -328,7 +345,7 @@ class AbstractNode:
                         self.NODE_TYPE, peer.node_type
                     )
                 )
-        self.outbound_peers = outbound_peer_models
+        self.outbound_peers = new_peer_models
 
     def on_updated_node_model(self, new_node_model: NodeModel):
         """
@@ -390,18 +407,6 @@ class AbstractNode:
 
         conn.advance_sent_bytes(bytes_sent)
 
-    def on_bytes_written_to_socket(self, file_no: int, bytes_written: int) -> None:
-        conn = self.connection_pool.get_by_fileno(file_no)
-
-        if conn is None:
-            logger.debug(
-                "Bytes written call for connection not in pool: {}",
-                file_no
-            )
-            return
-
-        conn.advance_bytes_written_to_socket(bytes_written)
-
     def fire_alarms(self) -> float:
         time_to_next = self.alarm_queue.fire_ready_alarms()
         if time_to_next is not None:
@@ -441,13 +446,13 @@ class AbstractNode:
         msg: AbstractMessage,
         broadcasting_conn: Optional[AbstractConnection] = None,
         prepend_to_queue: bool = False,
-        connection_types: Optional[List[ConnectionType]] = None
+        connection_types: Optional[Tuple[ConnectionType, ...]] = None
     ) -> List[AbstractConnection]:
         """
         Broadcasts message msg to connections of the specified type except requester.
         """
         if connection_types is None:
-            connection_types = [ConnectionType.RELAY_ALL]
+            connection_types = (ConnectionType.RELAY_ALL,)
         options = BroadcastOptions(broadcasting_conn, prepend_to_queue, connection_types)
         connections = self.broadcast_service.broadcast(msg, options)
         return connections
@@ -660,11 +665,12 @@ class AbstractNode:
         should_retry = SocketConnectionStates.DO_NOT_RETRY not in conn.socket_connection.state
 
         logger.debug("Breaking connection to {}. Attempting retry: {}", conn, should_retry)
-        conn.dispose()
+
         self.connection_pool.delete(conn)
         self.handle_connection_closed(
             should_retry, ConnectionPeerInfo(conn.endpoint, conn.CONNECTION_TYPE), conn.state
         )
+        conn.dispose()
 
     def _initialize_connection(
         self, socket_connection: AbstractSocketConnectionProtocol
@@ -705,7 +711,7 @@ class AbstractNode:
 
         logger.trace("Checking connection status: {}", conn)
 
-        if ConnectionState.ESTABLISHED in conn.state:
+        if conn.established:
             logger.trace("Connection is still established: {}", conn)
             self.num_retries_by_ip[(conn.peer_ip, conn.peer_port)] = 0
             return constants.CANCEL_ALARMS
@@ -732,9 +738,8 @@ class AbstractNode:
         """
         Returns Fibonnaci(n), where n is the number of retry attempts + 1, up to max of Fibonacci(8) == 13.
         """
-        golden_ratio = (1 + 5 ** .5) / 2
         sequence_number = min(self.num_retries_by_ip[(ip, port)] + 1, constants.MAX_CONNECT_TIMEOUT_INCREASE)
-        return int((golden_ratio ** sequence_number - (1 - golden_ratio) ** sequence_number) / 5 ** .5)
+        return utils.fibonacci(sequence_number)
 
     def _retry_init_client_socket(self, ip: str, port: int, connection_type: ConnectionType):
         self.num_retries_by_ip[(ip, port)] += 1
