@@ -1,4 +1,5 @@
 from abc import ABC
+from typing import Optional
 
 from bxcommon import constants
 from bxcommon.messages.bloxroute.abstract_bloxroute_message import AbstractBloxrouteMessage
@@ -9,7 +10,7 @@ from bxcommon.utils.object_hash import Sha256Hash
 class BlockHashMessage(AbstractBloxrouteMessage, ABC):
     PAYLOAD_LENGTH = crypto.SHA256_HASH_LEN + constants.CONTROL_FLAGS_LEN
 
-    def __init__(self, block_hash=None, buf=None):
+    def __init__(self, block_hash=None, buf=None) -> None:
         if buf is None:
             buf = bytearray(self.HEADER_LENGTH + self.PAYLOAD_LENGTH)
 
@@ -18,11 +19,13 @@ class BlockHashMessage(AbstractBloxrouteMessage, ABC):
             off += crypto.SHA256_HASH_LEN
 
         self.buf = buf
-        self._block_hash = None
+        self._block_hash: Optional[Sha256Hash] = None
         super(BlockHashMessage, self).__init__(self.MESSAGE_TYPE, self.PAYLOAD_LENGTH, buf)
 
-    def block_hash(self):
-        if self._block_hash is None:
+    def block_hash(self) -> Sha256Hash:
+        block_hash = self._block_hash
+        if block_hash is None:
             off = self.HEADER_LENGTH
-            self._block_hash = Sha256Hash(self._memoryview[off:off + crypto.SHA256_HASH_LEN])
-        return self._block_hash
+            block_hash = Sha256Hash(self._memoryview[off:off + crypto.SHA256_HASH_LEN])
+            self._block_hash = block_hash
+        return block_hash
