@@ -13,8 +13,18 @@ TRANSACTION_FEE_BUMP_INTERVAL_S = "bump_interval"
 TRANSACTION_JSON_PARAMS_KEY = "transaction_json"
 TRANSACTION_FLAG_PARAMS_KEY = "transaction_flag"
 PRIVATE_TRANSACTION_TIMEOUT_KEY = "timeout"
+BLOCK_NUMBER_PARAMS_KEY = "block_number"
+STATE_BLOCK_NUMBER_PARAMS_KEY = "state_block_number"
+TIMESTAMP_PARAMS_KEY = "timestamp"
+MIN_TIMESTAMP_PARAMS_KEY = "min_timestamp"
+MAX_TIMESTAMP_PARAMS_KEY = "max_timestamp"
+WALLET_API_KEY_PARAMS_KEY = "wallet_api_key"
 TAG_PARAMS_KEY = "tag"
+ALL_KEY = "all"
+POOLS_PARAMS_KEY = "pools"
+DETAIL_RESPONSE_PARAM_KEY = "detail_response"
 SYNCHRONOUS_PARAMS_KEY = "synchronous"
+SMART_MONITORING_PARAMS_KEY = "smart_monitoring"
 STATUS_TRACK_PARAMS_KEY = "status_track"
 NONCE_MONITORING_PARAMS_KEY = "nonce_monitoring"
 DETAILS_LEVEL_PARAMS_KEY = "details_level"
@@ -22,12 +32,16 @@ BLOCKCHAIN_PROTOCOL_PARAMS_KEY = "blockchain_protocol"
 BLOCKCHAIN_NETWORK_PARAMS_KEY = "blockchain_network"
 BLOCKCHAIN_NETWORK_NUM_PARAMS_KEY = "blockchain_network_num"
 NETWORK_NUM_PARAMS_KEY = "network_num"
+NETWORK_TRANSACTION_FEE_UPDATE_KEY = "network_tx_fee_update"
+ALLOWED_TIME_INTERVAL_SAME_NONCE_KEY = "allowed_time_interval_same_nonce"
+ALLOWED_NETWORK_TRANSACTION_FEE_CHANGE_SAME_NONCE_KEY = "allowed_network_tx_fee_change_same_nonce"
 ACCOUNT_ID_PARAMS_KEY = "account_id"
 ACCOUNT_CACHE_KEY_PARAMS_KEY = "account_cache_key"
 TX_SERVICE_FILE_NAME_PARAMS_KEY = "file_name"
 BLOCKCHAIN_PEER_PARAMS_KEY = "peer"
 AUTHORIZATION_HEADER_KEY = "Authorization"
 WEBSOCKET_HEADER_KEY = "upgrade"
+TRANSACTIONS_PARAMS_KEY = "transactions"
 RPC_SERVER_INIT_TIMEOUT_S = 10
 RPC_SERVER_STOP_TIMEOUT_S = 10
 HEALTHCHECK_INTERVAL = 60
@@ -49,6 +63,7 @@ JSON_RPC_RESULT = "result"
 JSON_RPC_ERROR = "error"
 JSON_RPC_MESSAGE = "message"
 JSON_RPC_DATA = "data"
+JSON_RPC_ERROR_CODE = "code"
 
 NEW_TRANSACTION_FEED_NAME = "newTxs"
 NEW_BLOCKS_FEED_NAME = "newBlocks"
