@@ -27,3 +27,6 @@ class RpcRequestType(SerializeableEnum):
     START_TRANSACTION_FEE_BUMP = 22
     STOP_TRANSACTION_FEE_BUMP = 23
     BLXR_TX_FEE_BUMP = 24
+    NETWORK_TX_FEE_UPDATE = 25
+    BLXR_SIMULATE_BUNDLE = 26
+    BLXR_SUBMIT_BUNDLE = 27
