@@ -1,3 +1,4 @@
+import os
 import struct
 from abc import ABCMeta
 
@@ -54,6 +55,25 @@ class Sha256Hash(AbstractObjectHash):
     def __str__(self):
         return convert.bytes_to_hex(self.binary)
 
+    def to_string(self, prefix: bool = False) -> str:
+        if prefix:
+            return f"0x{str(self)}"
+        else:
+            return str(self)
+
+    @classmethod
+    def from_string(cls, s: str) -> "Sha256Hash":
+        if s.startswith("0x"):
+            s = s[2:]
+
+        return cls(convert.hex_to_bytes(s))
+
+    @classmethod
+    def generate_object_hash(cls) -> "Sha256Hash":
+        raw_bytes = bytearray(0)
+        raw_bytes.extend(os.urandom(SHA256_HASH_LEN))
+        return Sha256Hash(raw_bytes)
+
 
 class ConcatHash(AbstractObjectHash):
     """
