@@ -29,7 +29,6 @@ class LogRecordType(Enum):
     TransactionAuditSummary = "stats.transaction.audit.summary"
     TransactionStatus = "transaction.status"
     TransactionTracing = "network_content.tx.tracing"
-    BlockAudit = "stats.block.audit"
     BlockAuditSummary = "stats.block.audit.summary"
     AuditUpdates = "stats.audit.updates"
     CustomerInfo = "stats.customer.info"
@@ -50,9 +49,10 @@ class LogRecordType(Enum):
     Config = "config"
     QuotaNotification = "stats.quota.notification"
     QuotaFillStatus = "stats.quota.fill"
-    TransactionQuota = "transaction.quota"
     TransactionFiltering = "transaction.filter"
     TxBlockchainStatusInfo = "stats.transaction.status"
-    PrivateTransaction = "stats.cloudapi.private_transaction"
+    PrivateTransaction = "stats.private_transaction"
     PaidTransaction = "stats.transaction.paid_transaction"
     TxDetectionTimeLocation = "stats.transaction.tx_detection_time_location"
+    TransactionMonitoring = "stats.transaction.monitoring"
+    MEVBundleTransaction = "stats.transaction.mev_bundle"
