@@ -3,10 +3,16 @@ from datetime import datetime, timedelta
 from datetime import time as dttime
 from typing import TypeVar, Optional, Callable, Any
 
+from bxutils import constants
+
 T = TypeVar("T")
 R = TypeVar("R")
 
 
+def fibonacci(sequence_number: int) -> int:
+    return int((constants.FIBONACCI_GOLDEN_RATIO ** sequence_number - (1 - constants.FIBONACCI_GOLDEN_RATIO) ** sequence_number) / 5 ** .5)
+
+
 def optional_map(val: Optional[T], mapper: Callable[[T], R]) -> Optional[R]:
     if val is None:
         return val
