@@ -155,8 +155,23 @@ class AbstractGatewayNode(AbstractNode, metaclass=ABCMeta):
 
         if opts.account_model:
             self.account_model = opts.account_model
+            node_cache.update_cache_file(
+                opts,
+                # pyre-fixme[16]: `Optional` has no attribute `account_id`
+                accounts={opts.account_model.account_id: self.account_model},
+            )
         else:
-            self.account_model = None
+            node_cache_info = node_cache.read(opts)
+            if (
+                node_cache_info
+                and node_cache_info.accounts
+                and node_cache_info.node_model
+                and node_cache_info.node_model.account_id is not None
+            ):
+                # pyre-fixme[6]: Expected `str` for 1st param but got `Optional[str]`
+                self.account_model = node_cache_info.accounts[node_cache_info.node_model.account_id]
+            else:
+                self.account_model = None
 
         self.quota_level = 0
         self.num_active_blockchain_peers = 0
@@ -398,7 +413,7 @@ class AbstractGatewayNode(AbstractNode, metaclass=ABCMeta):
         self.feed_manager.register_feed(NewBlockFeed())
 
     def send_bdn_performance_stats(self) -> int:
-        relay_connection = next(iter(self.connection_pool.get_by_connection_types([ConnectionType.RELAY_BLOCK])), None)
+        relay_connection = next(iter(self.connection_pool.get_by_connection_types((ConnectionType.RELAY_BLOCK,))), None)
         if not relay_connection:
             gateway_bdn_performance_stats_service.create_interval_data_object()
             return gateway_bdn_performance_stats_service.interval
@@ -620,7 +635,11 @@ class AbstractGatewayNode(AbstractNode, metaclass=ABCMeta):
     def broadcast_transactions_to_nodes(
         self, msg: AbstractMessage, broadcasting_conn: Optional[AbstractConnection]
     ) -> bool:
-        self.broadcast(msg, broadcasting_conn=broadcasting_conn, connection_types=[ConnectionType.BLOCKCHAIN_NODE])
+        self.broadcast(
+            msg,
+            broadcasting_conn=broadcasting_conn,
+            connection_types=(ConnectionType.BLOCKCHAIN_NODE,)
+        )
         return True
 
     def send_msg_to_remote_node(self, msg: AbstractMessage) -> None:
@@ -636,6 +655,13 @@ class AbstractGatewayNode(AbstractNode, metaclass=ABCMeta):
 
     def continue_retrying_connection(self, ip: str, port: int, connection_type: ConnectionType) -> bool:
         if connection_type == ConnectionType.BLOCKCHAIN_NODE:
+            self.num_active_blockchain_peers = len(
+                list(
+                    self.connection_pool.get_by_connection_types(
+                        (ConnectionType.BLOCKCHAIN_NODE,)
+                    )
+                )
+            )
             return self.num_active_blockchain_peers == 0 \
                 or ((ip, port) in self.time_blockchain_peer_conn_destroyed_by_ip and
                     time.time() - self.time_blockchain_peer_conn_destroyed_by_ip[(ip, port)]
@@ -669,8 +695,13 @@ class AbstractGatewayNode(AbstractNode, metaclass=ABCMeta):
             connection.peer_ip,
             connection.peer_port
         )
-        self.num_active_blockchain_peers = \
-            len(list(self.connection_pool.get_by_connection_types([ConnectionType.BLOCKCHAIN_NODE])))
+        self.num_active_blockchain_peers = len(
+            list(
+                self.connection_pool.get_by_connection_types(
+                    (ConnectionType.BLOCKCHAIN_NODE,)
+                )
+            )
+        )
 
     def on_blockchain_connection_destroyed(self, connection: AbstractGatewayBlockchainConnection) -> None:
         if BlockchainPeerInfo(connection.peer_ip, connection.peer_port) in self.blockchain_peers:
@@ -689,8 +720,14 @@ class AbstractGatewayNode(AbstractNode, metaclass=ABCMeta):
             connection.peer_port,
             connection.get_connection_state_details()
         )
-        self.num_active_blockchain_peers = \
-            max(0, len(list(self.connection_pool.get_by_connection_types([ConnectionType.BLOCKCHAIN_NODE]))) - 1)
+        self.num_active_blockchain_peers = len(
+            list(
+                self.connection_pool.get_by_connection_types(
+                    (ConnectionType.BLOCKCHAIN_NODE,)
+                )
+            )
+        )
+
         if self.num_active_blockchain_peers > 0:
             self.block_queuing_service_manager.remove_block_queuing_service(connection)
 
@@ -737,7 +774,7 @@ class AbstractGatewayNode(AbstractNode, metaclass=ABCMeta):
         if self.opts.sync_tx_service \
             and self.network_num not in self.last_sync_message_received_by_network \
                 and ConnectionType.RELAY_TRANSACTION in conn_type \
-                and len(list(self.connection_pool.get_by_connection_types([ConnectionType.RELAY_TRANSACTION]))) == 1:
+                and len(list(self.connection_pool.get_by_connection_types((ConnectionType.RELAY_TRANSACTION,)))) == 1:
             # set sync to false and updating sdn
             self.opts.has_fully_updated_tx_service = False
             self.requester.send_threaded_request(sdn_http_service.submit_tx_not_synced_event, self.opts.node_id)
@@ -916,13 +953,13 @@ class AbstractGatewayNode(AbstractNode, metaclass=ABCMeta):
         return blockchain_peers
 
     def has_active_blockchain_peer(self) -> bool:
-        for conn in self.connection_pool.get_by_connection_types([ConnectionType.BLOCKCHAIN_NODE]):
+        for conn in self.connection_pool.get_by_connection_types((ConnectionType.BLOCKCHAIN_NODE,)):
             if conn.is_active():
                 return True
         return False
 
     def get_any_active_blockchain_connection(self) -> Optional[AbstractConnection]:
-        for conn in self.connection_pool.get_by_connection_types([ConnectionType.BLOCKCHAIN_NODE]):
+        for conn in self.connection_pool.get_by_connection_types((ConnectionType.BLOCKCHAIN_NODE,)):
             if conn.is_active():
                 return conn
         return None
@@ -953,7 +990,7 @@ class AbstractGatewayNode(AbstractNode, metaclass=ABCMeta):
         return gateway_constants.ACTIVE_BLOCKCHAIN_PEERS_LIVELINESS_CHECK_S
 
     def check_relay_liveliness(self) -> None:
-        if not list(self.connection_pool.get_by_connection_types([ConnectionType.RELAY_ALL])):
+        if not list(self.connection_pool.get_by_connection_types((ConnectionType.RELAY_ALL,))):
             self.should_force_exit = True
             logger.error(log_messages.NO_ACTIVE_BDN_CONNECTIONS)
 
@@ -1033,49 +1070,50 @@ class AbstractGatewayNode(AbstractNode, metaclass=ABCMeta):
         super(AbstractGatewayNode, self).sync_tx_services()
         if self.opts.sync_tx_service:
             retry = True
-            if self.opts.split_relays:
-                relay_tx_connection: Optional[AbstractRelayConnection] = next(
-                    iter(self.connection_pool.get_by_connection_types([ConnectionType.RELAY_TRANSACTION])), None
-                )
-                relay_block_connection: Optional[AbstractRelayConnection] = next(
-                    iter(self.connection_pool.get_by_connection_types([ConnectionType.RELAY_BLOCK])), None
-                )
-
-                if (
-                    relay_tx_connection and relay_block_connection and
-                    relay_tx_connection.is_active() and relay_block_connection.is_active()
-                ):
-                    if self.transaction_sync_timeout_alarm_id:
-                        alarm_id = self.transaction_sync_timeout_alarm_id
-                        assert alarm_id is not None
-                        self.alarm_queue.unregister_alarm(alarm_id)
-                        self.transaction_sync_timeout_alarm_id = None
-                    self.transaction_sync_timeout_alarm_id = self.alarm_queue.register_alarm(
-                        constants.TX_SERVICE_CHECK_NETWORKS_SYNCED_S, self._transaction_sync_timeout
+            if self.has_active_blockchain_peer():
+                if self.opts.split_relays:
+                    relay_tx_connection: Optional[AbstractRelayConnection] = next(
+                        iter(self.connection_pool.get_by_connection_types((ConnectionType.RELAY_TRANSACTION,))), None
+                    )
+                    relay_block_connection: Optional[AbstractRelayConnection] = next(
+                        iter(self.connection_pool.get_by_connection_types((ConnectionType.RELAY_BLOCK,))), None
                     )
 
-                    # the sync with relay_tx must be the last one. since each call erase the previous call alarm
-                    relay_block_connection.tx_sync_service.send_tx_service_sync_req(self.network_num)
-                    relay_tx_connection.tx_sync_service.send_tx_service_sync_req(self.network_num)
-                    self._clear_transaction_service()
-                    retry = False
-            else:
-                relay_connection: Optional[AbstractRelayConnection] = next(
-                    iter(self.connection_pool.get_by_connection_types([ConnectionType.RELAY_ALL])), None
-                )
-                if relay_connection and relay_connection.is_active():
-                    if self.transaction_sync_timeout_alarm_id:
-                        alarm_id = self.transaction_sync_timeout_alarm_id
-                        assert alarm_id is not None
-                        self.alarm_queue.unregister_alarm(alarm_id)
-                        self.transaction_sync_timeout_alarm_id = None
+                    if (
+                        relay_tx_connection and relay_block_connection and
+                        relay_tx_connection.is_active() and relay_block_connection.is_active()
+                    ):
+                        if self.transaction_sync_timeout_alarm_id:
+                            alarm_id = self.transaction_sync_timeout_alarm_id
+                            assert alarm_id is not None
+                            self.alarm_queue.unregister_alarm(alarm_id)
+                            self.transaction_sync_timeout_alarm_id = None
+                        self.transaction_sync_timeout_alarm_id = self.alarm_queue.register_alarm(
+                            constants.TX_SERVICE_CHECK_NETWORKS_SYNCED_S, self._transaction_sync_timeout
+                        )
 
-                    self.transaction_sync_timeout_alarm_id = self.alarm_queue.register_alarm(
-                        constants.TX_SERVICE_CHECK_NETWORKS_SYNCED_S, self._transaction_sync_timeout
+                        # the sync with relay_tx must be the last one. since each call erase the previous call alarm
+                        relay_block_connection.tx_sync_service.send_tx_service_sync_req(self.network_num)
+                        relay_tx_connection.tx_sync_service.send_tx_service_sync_req(self.network_num)
+                        self._clear_transaction_service()
+                        retry = False
+                else:
+                    relay_connection: Optional[AbstractRelayConnection] = next(
+                        iter(self.connection_pool.get_by_connection_types((ConnectionType.RELAY_ALL,))), None
                     )
-                    relay_connection.tx_sync_service.send_tx_service_sync_req(self.network_num)
-                    self._clear_transaction_service()
-                    retry = False
+                    if relay_connection and relay_connection.is_active():
+                        if self.transaction_sync_timeout_alarm_id:
+                            alarm_id = self.transaction_sync_timeout_alarm_id
+                            assert alarm_id is not None
+                            self.alarm_queue.unregister_alarm(alarm_id)
+                            self.transaction_sync_timeout_alarm_id = None
+
+                        self.transaction_sync_timeout_alarm_id = self.alarm_queue.register_alarm(
+                            constants.TX_SERVICE_CHECK_NETWORKS_SYNCED_S, self._transaction_sync_timeout
+                        )
+                        relay_connection.tx_sync_service.send_tx_service_sync_req(self.network_num)
+                        self._clear_transaction_service()
+                        retry = False
 
             if retry:
                 logger.info("Relay connection is not ready to sync transaction state with BDN. Scheduling retry.")
