@@ -5,6 +5,7 @@ from bxcommon import constants
 from bxcommon.connections.connection_type import ConnectionType
 from bxcommon.connections.internal_node_connection import InternalNodeConnection
 from bxcommon.feed.feed import FeedKey
+from bxcommon.messages.abstract_message_factory import AbstractMessageFactory
 from bxcommon.messages.bloxroute.ack_message import AckMessage
 from bxcommon.messages.bloxroute.bloxroute_message_type import BloxrouteMessageType
 from bxcommon.network.abstract_socket_connection_protocol import AbstractSocketConnectionProtocol
@@ -44,8 +45,6 @@ class GatewayConnection(InternalNodeConnection["AbstractGatewayNode"]):
 
         self.hello_messages = gateway_constants.GATEWAY_HELLO_MESSAGES
         self.header_size = constants.STARTING_SEQUENCE_BYTES_LEN + constants.BX_HDR_COMMON_OFF
-
-        self.message_factory = gateway_message_factory
         self.message_handlers = {
             GatewayMessageType.HELLO: self.msg_hello,
             BloxrouteMessageType.ACK: self.msg_ack,
@@ -64,6 +63,9 @@ class GatewayConnection(InternalNodeConnection["AbstractGatewayNode"]):
         else:
             self.ordering = self.NULL_ORDERING
 
+    def connection_message_factory(self) -> AbstractMessageFactory:
+        return gateway_message_factory
+
     def on_connection_established(self):
         super().on_connection_established()
 
@@ -231,8 +233,6 @@ class GatewayConnection(InternalNodeConnection["AbstractGatewayNode"]):
         self.peer_desc = "%s %d" % (self.peer_ip, self.peer_port)
 
     def dispose(self):
-        super().dispose()
-
         if not self.from_me:
             if self.peer_id:
                 self.node.requester.send_threaded_request(
@@ -240,3 +240,4 @@ class GatewayConnection(InternalNodeConnection["AbstractGatewayNode"]):
                     self.node.opts.node_id,
                     self.peer_id
                 )
+        super().dispose()
