@@ -156,7 +156,7 @@ class GatewayOpts(CommonOpts):
 
         if not opts.cookie_file_path:
             opts.cookie_file_path = gateway_constants.COOKIE_FILE_PATH_TEMPLATE.format(
-                "{}_{}".format(get_sdn_hostname(opts.sdn_url), opts.external_ip)
+                "{}_{}".format(get_sdn_hostname(opts.sdn_url), opts.external_port)
             )
 
         opts.min_peer_relays_count = 1
