@@ -1,12 +1,11 @@
 from typing import List
 
-import rlp
-
+import blxr_rlp as rlp
 from bxutils.logging.log_level import LogLevel
 
 from bxgateway.messages.eth.protocol.eth_protocol_message import EthProtocolMessage
 from bxgateway.messages.eth.protocol.eth_protocol_message_type import EthProtocolMessageType
-from bxgateway.messages.eth.serializers.block_header import BlockHeader
+from bxcommon.messages.eth.serializers.block_header import BlockHeader
 from bxcommon.utils.blockchain_utils.eth import rlp_utils
 
 
