@@ -1,4 +1,4 @@
-import rlp
+import blxr_rlp as rlp
 from typing import List, Optional
 
 from bxutils.logging.log_level import LogLevel
@@ -9,9 +9,9 @@ from bxcommon.utils.object_hash import Sha256Hash
 from bxgateway.messages.eth.new_block_parts import NewBlockParts
 from bxgateway.messages.eth.protocol.eth_protocol_message import EthProtocolMessage
 from bxgateway.messages.eth.protocol.eth_protocol_message_type import EthProtocolMessageType
-from bxgateway.messages.eth.serializers.block import Block
+from bxcommon.messages.eth.serializers.block import Block
 from bxcommon.messages.eth.serializers.transaction import Transaction
-from bxgateway.messages.eth.serializers.block_header import BlockHeader
+from bxcommon.messages.eth.serializers.block_header import BlockHeader
 from bxcommon.utils.blockchain_utils.eth import rlp_utils, eth_common_utils
 
 
