@@ -12,10 +12,13 @@ from bxcommon.models.transaction_flag import TransactionFlag
 from bxcommon.network.ip_endpoint import IpEndpoint
 from bxcommon.rpc import rpc_constants
 from bxcommon.test_utils import helpers
+from bxcommon.test_utils.fixture import eth_fixtures
 from bxcommon.test_utils.mocks.mock_connection import MockConnection
 from bxcommon.test_utils.mocks.mock_socket_connection import MockSocketConnection
-from bxgateway.connections.eth.eth_base_connection import EthBaseConnection
 from bxgateway.connections.eth.eth_gateway_node import EthGatewayNode
+from bxgateway.connections.eth.eth_node_connection import EthNodeConnection
+from bxgateway.messages.eth.eth_normal_message_converter import EthNormalMessageConverter
+from bxgateway.testing.mocks.mock_blockchain_connection import MockMessageConverter
 from bxutils import constants as utils_constants
 from bxcommon.models.bdn_account_model_base import BdnAccountModelBase
 from bxcommon.models.bdn_service_model_base import BdnServiceModelBase, FeedServiceModelBase
@@ -75,11 +78,10 @@ class AbstractGatewayRpcIntegrationTest(AbstractTestCase):
         self.gateway_node.requester.start()
         self.gateway_node.account_id = ACCOUNT_ID
         self.node_endpoint_1 = IpEndpoint("127.0.0.1", 7000)
-        self.blockchain_connection_1 = EthBaseConnection(
-            MockSocketConnection(
-                node=self.gateway_node, ip_address="127.0.0.1", port=7000), cast(EthGatewayNode, self.gateway_node)
+        self.blockchain_connection_1 = EthNodeConnection(
+            MockSocketConnection(1, node=self.gateway_node, ip_address="127.0.0.1", port=7000), cast(EthGatewayNode, self.gateway_node)
         )
-        self.blockchain_connection_1.state = ConnectionState.ESTABLISHED
+        self.blockchain_connection_1.on_connection_established()
 
     @abstractmethod
     def get_gateway_opts(self) -> GatewayOpts:
@@ -129,8 +131,6 @@ class AbstractGatewayRpcIntegrationTest(AbstractTestCase):
         self.assertEqual("1", result.id)
         self.assertIsNone(result.error)
         self.assertEqual(TRANSACTION_HASH, result.result["tx_hash"])
-        self.assertEqual(ACCOUNT_ID, result.result["account_id"])
-        self.assertEqual(TransactionFlag.PAID_TX.name.lower(), result.result["transaction_flag"].lower())
 
         self.assertEqual(1, len(self.gateway_node.broadcast_messages))
         self.assertEqual(
@@ -138,6 +138,53 @@ class AbstractGatewayRpcIntegrationTest(AbstractTestCase):
             self.gateway_node.broadcast_messages[0][0].tx_hash()
         )
 
+    @async_test
+    async def test_blxr_tx_ethereum_berlin(self):
+        self.gateway_node.message_converter = EthNormalMessageConverter()
+        self.gateway_node.network_num = 5
+
+        # legacy
+        result = await self.request(BxJsonRpcRequest(
+            "1",
+            RpcRequestType.BLXR_TX,
+            {
+                rpc_constants.TRANSACTION_PARAMS_KEY: convert.bytes_to_hex(
+                    eth_fixtures.LEGACY_TRANSACTION
+                ),
+                rpc_constants.STATUS_TRACK_PARAMS_KEY: "True"
+            }
+        ))
+        self.assertEqual("1", result.id)
+        self.assertIsNone(result.error)
+        self.assertEqual(eth_fixtures.LEGACY_TRANSACTION_HASH, result.result["tx_hash"])
+
+        self.assertEqual(1, len(self.gateway_node.broadcast_messages))
+        self.assertEqual(
+            Sha256Hash(convert.hex_to_bytes(eth_fixtures.LEGACY_TRANSACTION_HASH)),
+            self.gateway_node.broadcast_messages[0][0].tx_hash()
+        )
+
+        # access list
+        result = await self.request(BxJsonRpcRequest(
+            "1",
+            RpcRequestType.BLXR_TX,
+            {
+                rpc_constants.TRANSACTION_PARAMS_KEY: convert.bytes_to_hex(
+                    eth_fixtures.ACCESS_LIST_TRANSACTION
+                ),
+                rpc_constants.STATUS_TRACK_PARAMS_KEY: "True"
+            }
+        ))
+        self.assertEqual("1", result.id)
+        self.assertIsNone(result.error)
+        self.assertEqual(eth_fixtures.ACCESS_LIST_TRANSACTION_HASH, result.result["tx_hash"])
+
+        self.assertEqual(2, len(self.gateway_node.broadcast_messages))
+        self.assertEqual(
+            Sha256Hash(convert.hex_to_bytes(eth_fixtures.ACCESS_LIST_TRANSACTION_HASH)),
+            self.gateway_node.broadcast_messages[1][0].tx_hash()
+        )
+
     @async_test
     async def test_blxr_tx_expired(self):
         self.gateway_node.account_model.is_account_valid = MagicMock(return_value=False)
@@ -195,8 +242,6 @@ class AbstractGatewayRpcIntegrationTest(AbstractTestCase):
         self.assertEqual("1", result.id)
         self.assertIsNone(result.error)
         self.assertEqual("ad6f9332384194f80d8e49af8f093ad019b3f6b7173eb2956a46c9a0d8c4d03c", result.result["tx_hash"])
-        self.assertEqual(ACCOUNT_ID, result.result["account_id"])
-        self.assertEqual(TransactionFlag.PAID_TX.name.lower(), result.result["transaction_flag"].lower())
 
         self.assertEqual(1, len(self.gateway_node.broadcast_messages))
         self.assertEqual(
@@ -316,9 +361,9 @@ class AbstractGatewayRpcIntegrationTest(AbstractTestCase):
             20, self.node_endpoint_1.ip_address, self.node_endpoint_1.port, self.blockchain_connection_1
         )
 
-        blockchain_connection_2 = EthBaseConnection(
-            MockSocketConnection(node=self.gateway_node, ip_address="127.0.0.1", port=333), self.gateway_node)
-        blockchain_connection_2.state = ConnectionState.ESTABLISHED
+        blockchain_connection_2 = EthNodeConnection(
+            MockSocketConnection(1, node=self.gateway_node, ip_address="127.0.0.1", port=333), self.gateway_node)
+        blockchain_connection_2.on_connection_established()
         self.gateway_node.mock_add_blockchain_peer(blockchain_connection_2)
         node_endpoint_2 = IpEndpoint("127.0.0.1", 333)
         self.gateway_node.connection_pool.add(
@@ -402,7 +447,7 @@ class AbstractGatewayRpcIntegrationTest(AbstractTestCase):
 
     @async_test
     async def test_remove_blockchain_peer(self):
-        conn = MockConnection(MockSocketConnection(9, ip_address="127.0.0.1", port=30302), self.gateway_node)
+        conn = MockConnection(MockSocketConnection(9, self.gateway_node, ip_address="127.0.0.1", port=30302), self.gateway_node)
         conn.mark_for_close = MagicMock()
         self.gateway_node.connection_pool.add(9, "127.0.0.1", 30302, conn)
         self.gateway_node.blockchain_peers.add(BlockchainPeerInfo("127.0.0.1", 30302, "d76d7d11a822fab02836f8b0ea462205916253eb630935d15191fb6f9d218cd94a768fc5b3d5516b9ed5010a4765f95aea7124a39d0ab8aaf6fa3d57e21ef396"))
