@@ -5,14 +5,13 @@ from collections import defaultdict
 from typing import TYPE_CHECKING
 
 from bxutils import logging
-from bxgateway import log_messages
 from bxutils.logging import log_config
 from bxutils.logging import log_level
-
-from bxcommon.models.config.gateway_node_config_model import GatewayNodeConfigModel
 from bxcommon.utils import model_loader
 from bxcommon.utils import config
 
+from bxgateway import log_messages
+from bxgateway.models.config.gateway_node_config_model import GatewayNodeConfigModel
 from bxgateway import gateway_constants
 
 if TYPE_CHECKING:
@@ -35,8 +34,9 @@ def read_config_file(full_path: str) -> GatewayNodeConfigModel:
         try:
             with open(full_path, "r") as f:
                 raw_input = f.read()
-                config_model = model_loader.load_model_from_json(model_class=GatewayNodeConfigModel,
-                                                                 model_params=raw_input)
+                config_model = model_loader.load_model_from_json(
+                    model_class=GatewayNodeConfigModel, model_params=raw_input
+                )
                 config_file_last_updated[full_path] = file_mod_time
                 last_config_model[full_path] = config_model
         except (TypeError, JSONDecodeError):
